local _, Addon = ...
local BreedInfo = LibStub('LibPetBreedInfo-1.0')
local Tamer, Pet = Addon:NewModule('Tamer'), Addon:NewModule('TamerPet')

Tamer.__index = Tamer
Pet.__index = Pet


--[[ Tamer ]]--

function Tamer:Get(name)
	local data = PetTracker_Tamers[name]
	if data then
		local model, pets = data:match('^(%w+):(.*)$')
		local tamer = setmetatable({
			name = name,
			model = tonumber(model, 36)
		}, self)

		for name, specie, model, level, quality in pets:gmatch('([^:]+):(%w+):(%w+):(%w)(%w)') do
			tinsert(tamer, setmetatable({
				Name = name,
				Specie = tonumber(specie, 36),
				Model = tonumber(model, 36),
				Level = tonumber(level, 36),
				Quality = tonumber(quality, 36)
			}, Pet))
		end

		return tamer
	end
end

for _, key in pairs {'Level', 'Quality'} do
	Tamer['Get' .. key] = function(self)
		local value = 0
		for i, pet in ipairs(self) do
			value = value + pet['Get' .. key](pet)
		end

		return floor(value / #self + .5)
	end
end


--[[ Pets ]]--

for _, key in pairs {'Name', 'Specie', 'Model', 'Level', 'Quality'} do
	Pet['Get' .. key] = function(self)
		return self[key]
	end
end

function Pet:GetStats()
	return BreedInfo:GetPetPredictedStats(self.Specie, self:GetBreed(), self.Quality, self.Level)
end

function Pet:GetBreed()
	return BreedInfo:GetAvailableBreeds(self.Specie)[1]
end

function Pet:GetAbilityID(i)
	local ids = C_PetJournal.GetPetAbilityList(self.Specie)
	for _, id in pairs(ids) do
		i = i - 1
		if i == 0 then
			return id
		end
	end
end

function Pet:GetAbilityStatus(i)
	return 0, nil
end