local Addon = PetTracker
local Journal = PetTrackerTamerJournal
local Tab = TabAppender_New('Tamers', PetJournalParent)
local Order = {}


--[[ Startup ]]--

function Journal:Startup()
	for name in pairs(PetTracker_Tamers) do
		tinsert(Order, Addon.Tamer:Get(name))
	end

	sort(Order, function(a,b)
		local x, y = a:GetLevel(), b:GetLevel()
		return x < y or x == y and a:GetQuality() < b:GetQuality()
	end)

	self.Slots = PetTracker.JournalSlot:CreateLine('TOP', self.RightInset, 0, 104)
	self.Count.Number:SetText(#Order)

	HybridScrollFrame_CreateButtons(self.List, 'PetTrackerTamerButton', 44, 0)
	self.List:update()
	self.List:onClick(self.List.buttons[2])

	local updateTab = PetJournalParent_UpdateSelectedTab
	function PetJournalParent_UpdateSelectedTab(parent)
		if PanelTemplates_GetSelectedTab(parent) == Tab:GetID() then
			MountJournal:Hide()
			PetJournal:Hide()
			self:Show()
		else
			updateTab(parent)
			self:Hide()
		end
	end

	local TEMP = self.PetCardInset:CreateFontString(nil, nil, 'GameFontHighlightLarge')
	TEMP:SetText("What goes here? You choose!\n We're currently looking for suggestions.")
	TEMP:SetAllPoints()
end

function Tab:OnClick()
	PetJournalParent_UpdateSelectedTab(PetJournalParent)
end


--[[ List ]]--

function Journal.List:update()
	local self = Journal.List
	local buttons = self.buttons
	local off = HybridScrollFrame_GetOffset(self)

	for i = 1, #buttons do
		local button = buttons[i]
		local tamer = Order[i + off]

		if tamer then
			button.name:SetText(tamer.name)
			button.model:SetDisplayInfo(tamer.model)
			button.model.level:SetText(tamer:GetLevel())
			button.model.quality:SetVertexColor(Addon:GetQualityColor(tamer:GetQuality()))
			button.selectedTexture:SetShown(tamer == self.tamer)
		end

		button:SetShown(tamer)
		button.tamer = tamer
	end

	HybridScrollFrame_Update(self, #Order * 46, self:GetHeight())
end

function Journal.List:onClick(button)
	local slots = self:GetParent().Slots
	for i, slot in ipairs(slots) do
		slot:Display(button.tamer[i])
	end

	self.tamer = button.tamer
	self:update()
end

Journal:Startup()